@@ -1,6 +1,6 @@
 from contextlib import closing
 from inspect import cleandoc
-from pkg_resources import get_entry_map
+from pkg_resources import iter_entry_points
 from typing import List, Optional, Type
 
 from click import Command, Context, MultiCommand
@@ -11,8 +11,8 @@ from mend.protocols import Generator, Plugin
 
 def load_generators() -> dict[str, Type[Generator]]:
     return {
-        name: module.load()
-        for name, module in get_entry_map("mend", "mend.generators").items()
+        entry_point.name: entry_point.load()
+        for entry_point in iter_entry_points("mend.generators")
     }
 
 
